{% extends "base.html" %}

{% block site_meta %}
  {{ super() }}
  {# Disable search indexing unless we're building for ReadTheDocs (see #10496) #}
  {% if page.canonical_url != 'https://docs.netbox.dev/' %}
    <meta name="robots" content="noindex">
  {% endif %}
{% endblock %}