// Overrides to native HTML elements (i.e., not bootstrap classes or custom components).

body {
  color: var(--nbx-body-color);
  background-color: var(--nbx-body-bg);
  font-size: $font-size-sm;
}

pre {
  white-space: pre;
}

// Force <small/> elements to make text smaller.
small {
  font-size: smaller !important;
}

// Fix the hideous way Safari shows button anchor elements.
a[type='button'] {
  -webkit-appearance: unset !important;
}

// Ensure elements with data-href set show the correct cursor.
// data-href is set on non non-anchor elements that need to redirect the user to a URL when
// clicked, but where an anchor element does not suffice or is not supported.
*[data-href] {
  cursor: pointer;
}

.form-control:not([type='file']) {
  font-size: inherit;
}

.badge {
  font-size: $font-size-xs;
}

/* clears the 'X' in search inputs from webkit browsers */
input[type='search']::-webkit-search-decoration,
input[type='search']::-webkit-search-cancel-button,
input[type='search']::-webkit-search-results-button,
input[type='search']::-webkit-search-results-decoration {
  -webkit-appearance: none !important;
}

// Remove x-axis padding from highlighted text
mark {
  padding-left: 0;
  padding-right: 0;
}