<!-- Log Messages from FastAPI backend -->
<h1 id="log-messages">Log Messages</h1>
<div style='overflow-y: auto; width: 100%; height: 400px;' id="scrollable-div">
    <div class="card" style="flex-direction: cloumn; overflow-y: auto">
        <ul id='messages' style='overflow: auto; flex-direction: cloumn-reverse; list-style-type: none;'>
        </ul>
    </div>
</div>