{# Footer links for the core Proxbox #}
{# Proxbox Custom Links #}
<li class="nav-item dropdown dropup">
    <a type="button" class="nav-link dropdown-toggle text-primary" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
        <i title="Proxbox Plugin" class="mdi mdi-puzzle" data-bs-placement="top" data-bs-toggle="tooltip"></i>
    </a>
    <ul class="dropdown-menu disabled" aria-labelledby="navbarDropdown">
        <li>
            {# Proxbox - Documentation #}
            <a type="button" class="dropdown-item" href="https://github.com/N-Multifibra/netbox-proxbox/blob/develop/README.md" target="_blank">
                <i title="Proxbox | Docs" class="mdi mdi-book-open-variant text-primary" data-bs-placement="top" data-bs-toggle="tooltip"></i>  Docs
            </a>
        <li>
            {# Proxbox - GitHub #}
            <a type="button" class="dropdown-item" href="https://github.com/N-Multifibra/netbox-proxbox" target="_blank">
                <i title="Proxbox | Source Code" class="mdi mdi-github text-primary" data-bs-placement="top" data-bs-toggle="tooltip"></i> GitHub
            </a>
        </li>
        <li>
            {# Proxbox - Telegram (Brazil) #}
            <a type="button" class="dropdown-item" href="https://t.me/netboxbr" target="_blank">
                <i title="Proxbox | Telegram (Brazil)" class="mdi mdi-telegram text-primary" data-bs-placement="top" data-bs-toggle="tooltip"></i> Telegram (BR)
            </a>
        </li>
        <li>
            <hr class="dropdown-divider">
        </li>
        <li>
            <span class="dropdown-item disabled">Proxbox (v0.0.3)</span>
        </li>
    </ul>
</li>

